"""
from rest_framework import status
from rest_framework.decorators import api_view, renderer_classes, parser_classes, authentication_classes
from rest_framework.parsers import JSONParser
from rest_framework.renderers import JSONRenderer
from rest_framework.response import Response

from django.core.exceptions import ImproperlyConfigured

from django_keycloak_lma import serializers as keycloak_serializers
from django_keycloak_lma.auth.backends import KeycloakPasswordAuthentication, KeycloakTokenAuthentication
from django_keycloak_lma.services import oidc_profile

from . import serializers


@api_view(['POST'])
@renderer_classes([JSONRenderer])
@parser_classes([JSONParser])
@authentication_classes([KeycloakPasswordAuthentication])
def login(request):
    if not hasattr(request, 'auth'):
        raise Exception("Section 'auth' was not found")

    auth_data = keycloak_serializers.TokenSerializer(request.auth).data

    return Response(auth_data, status=status.HTTP_200_OK)


@api_view(['POST'])
@renderer_classes([JSONRenderer])
@parser_classes([JSONParser])
@authentication_classes([KeycloakTokenAuthentication])
def check_access(request):

    return Response(status=status.HTTP_200_OK)


@api_view(['POST'])
@renderer_classes([JSONRenderer])
@parser_classes([JSONParser])
def refresh_token(request):
    if not hasattr(request, 'realm'):
        raise ImproperlyConfigured('Add BaseKeycloakMiddleware to middlewares')

    serializer = serializers.RefreshTokenSerializer(data=request.data)
    if not serializer.is_valid():
        raise Exception(serializer.errors)

    profile = oidc_profile.refresh_token(request.realm.client, serializer.validated_data["refresh"])
    auth_data = keycloak_serializers.TokenSerializer(profile).data

    return Response(auth_data, status=status.HTTP_200_OK)
"""
